"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QDataStream(QIODeviceBase):
    """
    https://doc.qt.io/qt-6/qdatastream.html

    **Detailed Description**

    A data stream is a binary stream of encoded information which is 100%
    independent of the host computer's operating system, CPU or byte order. For
    example, a data stream that is written by a PC under Windows can be read by
    a Sun SPARC running Solaris.

    You can also use a data stream to read/write **raw unencoded binary data** .
    If you want a "parsing" input stream, see **QTextStream** .

    The QDataStream class implements the serialization of C++'s basic data
    types, like `char`, `short`, `int`, `char *`, etc. Serialization of more
    complex data is accomplished by breaking up the data into primitive units.

    A data stream cooperates closely with a **QIODevice** . A **QIODevice**
    represents an input/output medium one can read data from and write data to.
    The **QFile**  class is an example of an I/O device.

    Example (write binary data to a stream):

    **QFile**  file("file.dat");
        file.open(**QIODevice** ::WriteOnly);
    **QDataStream**  out(&file);   // we will serialize the data into the file
    out << **QString** ("the answer is");   // serialize a string
        out <<
    (**qint32** )42;        // serialize an integer

    Example (read binary data from a stream):

    **QFile**  file("file.dat");
        file.open(**QIODevice** ::ReadOnly);
    **QDataStream**  in(&file);    // read the data serialized from the file
    **QString**  str;
        **qint32**  a;
        in >> str >> a;           //
    extract "the answer is" and 42

    Each item written to the stream is written in a predefined binary format
    that varies depending on the item's type. Supported Qt types include
    **QBrush** , **QColor** , **QDateTime** , **QFont** , **QPixmap** ,
    **QString** , **QVariant**  and many others. For the complete list of all Qt
    types supporting data streaming see **Serializing Qt Data Types** .

    For integers it is best to always cast to a Qt integer type for writing, and
    to read back into the same Qt integer type. This ensures that you get
    integers of the size you want and insulates you from compiler and platform
    differences.

    Enumerations can be serialized through QDataStream without the need of
    manually defining streaming operators. Enum classes are serialized using the
    declared size.

    To take one example, a `char *` string is written as a 32-bit integer equal
    to the length of the string including the '\\0' byte, followed by all the
    characters of the string including the '\\0' byte. When reading a `char *`
    string, 4 bytes are read to create the 32-bit length value, then that many
    characters for the `char *` string including the '\\0' terminator are read.

    The initial I/O device is usually set in the constructor, but can be changed
    with **setDevice** (). If you've reached the end of the data (or if there is
    no I/O device set) **atEnd** () will return true.

    **Versioning**

    QDataStream's binary format has evolved since Qt 1.0, and is likely to
    continue evolving to reflect changes done in Qt. When inputting or
    outputting complex types, it's very important to make sure that the same
    version of the stream (**version** ()) is used for reading and writing. If
    you need both forward and backward compatibility, you can hardcode the
    version number in the application:

    stream.setVersion(**QDataStream** ::Qt_4_0);

    If you are producing a new binary data format, such as a file format for
    documents created by your application, you could use a QDataStream to write
    the data in a portable format. Typically, you would write a brief header
    containing a magic string and a version number to give yourself room for
    future expansion. For example:

    **QFile**  file("file.xxx");
        file.open(**QIODevice** ::WriteOnly);
    **QDataStream**  out(&file);

        // Write a header with a "magic
    number" and a version
        out << (**quint32** )0xA0B0C0D0;
        out <<
    (**qint32** )123;

        out.setVersion(**QDataStream** ::Qt_4_0);
    // Write the data
        out << lots_of_interesting_data;

    Then read it in with:

    **QFile**  file("file.xxx");
        file.open(**QIODevice** ::ReadOnly);
    **QDataStream**  in(&file);

        // Read and check the header
    **quint32**  magic;
        in >> magic;
        if (magic != 0xA0B0C0D0)
    return XXX_BAD_FILE_FORMAT;

        // Read the version
        **qint32**
    version;
        in >> version;
        if (version < 100)
            return
    XXX_BAD_FILE_TOO_OLD;
        if (version > 123)
            return
    XXX_BAD_FILE_TOO_NEW;

        if (version <= 110)
    in.setVersion(**QDataStream** ::Qt_3_2);
        else
    in.setVersion(**QDataStream** ::Qt_4_0);

        // Read the data
        in >>
    lots_of_interesting_data;
        if (version >= 120)
            in >>
    data_new_in_XXX_version_1_2;
        in >> other_interesting_data;

    You can select which byte order to use when serializing data. The default
    setting is big-endian (MSB first). Changing it to little-endian breaks the
    portability (unless the reader also changes to little-endian). We recommend
    keeping this setting unless you have special requirements.

    **Reading and Writing Raw Binary Data**

    You may wish to read/write your own raw binary data to/from the data stream
    directly. Data may be read from the stream into a preallocated `char *`
    using **readRawData** (). Similarly data can be written to the stream using
    **writeRawData** (). Note that any encoding/decoding of the data must be
    done by you.

    A similar pair of functions is **readBytes** () and **writeBytes** (). These
    differ from their **raw** counterparts as follows: **readBytes** () reads a
    quint32 which is taken to be the length of the data to be read, then that
    number of bytes is read into the preallocated `char *`; **writeBytes** ()
    writes a quint32 containing the length of the data, followed by the data.
    Note that any encoding/decoding of the data (apart from the length quint32)
    must be done by you.

    **Reading and Writing Qt Collection Classes**

    The Qt container classes can also be serialized to a QDataStream. These
    include **QList** , **QSet** , **QHash** , and **QMap** . The stream
    operators are declared as non-members of the classes.

    **Reading and Writing Other Qt Classes**

    In addition to the overloaded stream operators documented here, any Qt
    classes that you might want to serialize to a QDataStream will have
    appropriate stream operators declared as non-member of the class:

    **QDataStream**  &operator<<(**QDataStream**  &, const QXxx &);
    **QDataStream**  &operator>>(**QDataStream**  &, QXxx &);

    For example, here are the stream operators declared as non-members of the
    **QImage**  class:

    **QDataStream**  & operator<< (**QDataStream** & stream, const **QImage** &
    image);
            **QDataStream**  & operator>> (**QDataStream** & stream,
    **QImage** & image);

    To see if your favorite Qt class has similar stream operators defined, check
    the **Related Non-Members** section of the class's documentation page.

    **Using Read Transactions**

    When a data stream operates on an asynchronous device, the chunks of data
    can arrive at arbitrary points in time. The QDataStream class implements a
    transaction mechanism that provides the ability to read the data atomically
    with a series of stream operators. As an example, you can handle incomplete
    reads from a socket by using a transaction in a slot connected to the
    readyRead() signal:

    in.startTransaction();
        **QString**  str;
        **qint32**  a;
        in >>
    str >> a; // try to read packet atomically

        if
    (!in.commitTransaction())
            return;     // wait for more data

    If no full packet is received, this code restores the stream to the initial
    position, after which you need to wait for more data to arrive.

    **See also** **QTextStream**  and **QVariant** .
    """

    class FloatingPointPrecision(enum.Enum):
        SinglePrecision: QDataStream = ...
        DoublePrecision: QDataStream = ...

    class Status(enum.Enum):
        Ok: QDataStream = ...
        ReadPastEnd: QDataStream = ...
        ReadCorruptData: QDataStream = ...
        WriteFailed: QDataStream = ...

    class ByteOrder(enum.Enum):
        BigEndian: QDataStream = ...
        LittleEndian: QDataStream = ...

    class Version(enum.IntEnum):
        Qt_1_0: QDataStream = ...
        Qt_2_0: QDataStream = ...
        Qt_2_1: QDataStream = ...
        Qt_3_0: QDataStream = ...
        Qt_3_1: QDataStream = ...
        Qt_3_3: QDataStream = ...
        Qt_4_0: QDataStream = ...
        Qt_4_1: QDataStream = ...
        Qt_4_2: QDataStream = ...
        Qt_4_3: QDataStream = ...
        Qt_4_4: QDataStream = ...
        Qt_4_5: QDataStream = ...
        Qt_4_6: QDataStream = ...
        Qt_4_7: QDataStream = ...
        Qt_4_8: QDataStream = ...
        Qt_4_9: QDataStream = ...
        Qt_5_0: QDataStream = ...
        Qt_5_1: QDataStream = ...
        Qt_5_2: QDataStream = ...
        Qt_5_3: QDataStream = ...
        Qt_5_4: QDataStream = ...
        Qt_5_5: QDataStream = ...
        Qt_5_6: QDataStream = ...
        Qt_5_7: QDataStream = ...
        Qt_5_8: QDataStream = ...
        Qt_5_9: QDataStream = ...
        Qt_5_10: QDataStream = ...
        Qt_5_11: QDataStream = ...
        Qt_5_12: QDataStream = ...
        Qt_5_13: QDataStream = ...
        Qt_5_14: QDataStream = ...
        Qt_5_15: QDataStream = ...
        Qt_6_0: QDataStream = ...
        Qt_6_1: QDataStream = ...
        Qt_6_2: QDataStream = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#QDataStream

        **QDataStream::QDataStream()**

        Constructs a data stream that has no I/O device.

        **See also** **setDevice** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#QDataStream-1

        **QDataStream::QDataStream(QIODevice * d )**

        Constructs a data stream that uses the I/O device **d**.

        **See also** **setDevice** () and **device** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: QByteArray, flags: QIODeviceBase.OpenModeFlag) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#QDataStream-2

        **QDataStream::QDataStream(QByteArray * a , QIODeviceBase::OpenMode mode
        )**

        Constructs a data stream that operates on a byte array, **a**. The
        **mode** describes how the device is to be used.

        Alternatively, you can use QDataStream(const **QByteArray**  &) if you
        just want to read from a byte array.

        Since **QByteArray**  is not a **QIODevice**  subclass, internally a
        **QBuffer**  is created to wrap the byte array.
        """
        ...

    @typing.overload
    def __init__(self, a0: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#QDataStream-3

        **QDataStream::QDataStream(const QByteArray & a )**

        Constructs a read-only data stream that operates on byte array **a**.
        Use QDataStream(**QByteArray** *, int) if you want to write to a byte
        array.

        Since **QByteArray**  is not a **QIODevice**  subclass, internally a
        **QBuffer**  is created to wrap the byte array.
        """
        ...

    def writeQVariantHash(self, qvarhash: typing.Dict[str, typing.Any]) -> None:
        ...

    def readQVariantHash(self) -> typing.Dict[str, typing.Any]:
        ...

    def writeQVariantMap(self, qvarmap: typing.Dict[str, typing.Any]) -> None:
        ...

    def readQVariantMap(self) -> typing.Dict[str, typing.Any]:
        ...

    def writeQVariantList(self, qvarlst: typing.Iterable[typing.Any]) -> None:
        ...

    def readQVariantList(self) -> typing.List[typing.Any]:
        ...

    def writeQVariant(self, qvar: typing.Any) -> None:
        ...

    def readQVariant(self) -> typing.Any:
        ...

    def writeQStringList(self, qstrlst: typing.Iterable[str]) -> None:
        ...

    def readQStringList(self) -> typing.List[str]:
        ...

    def writeQString(self, qstr: str) -> None:
        ...

    def readQString(self) -> str:
        ...

    def writeString(self, str: bytes) -> None:
        ...

    def writeDouble(self, f: float) -> None:
        ...

    def writeFloat(self, f: float) -> None:
        ...

    def writeBool(self, i: bool) -> None:
        ...

    def writeUInt64(self, i: int) -> None:
        ...

    def writeInt64(self, i: int) -> None:
        ...

    def writeUInt32(self, i: int) -> None:
        ...

    def writeInt32(self, i: int) -> None:
        ...

    def writeUInt16(self, i: int) -> None:
        ...

    def writeInt16(self, i: int) -> None:
        ...

    def writeUInt8(self, i: int) -> None:
        ...

    def writeInt8(self, i: int) -> None:
        ...

    def writeInt(self, i: int) -> None:
        ...

    def readString(self) -> bytes:
        ...

    def readDouble(self) -> float:
        ...

    def readFloat(self) -> float:
        ...

    def readBool(self) -> bool:
        ...

    def readUInt64(self) -> int:
        ...

    def readInt64(self) -> int:
        ...

    def readUInt32(self) -> int:
        ...

    def readInt32(self) -> int:
        ...

    def readUInt16(self) -> int:
        ...

    def readInt16(self) -> int:
        ...

    def readUInt8(self) -> int:
        ...

    def readInt8(self) -> int:
        ...

    def readInt(self) -> int:
        ...

    def abortTransaction(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#abortTransaction

        **[since 5.7] void QDataStream::abortTransaction()**

        Aborts a read transaction.

        This function is commonly used to discard the transaction after higher-
        level protocol errors or loss of stream synchronization.

        If called on an inner transaction, aborting is delegated to the
        outermost transaction, and subsequently started inner transactions are
        forced to fail.

        For the outermost transaction, discards the restoration point and any
        internally duplicated data of the stream. Will not affect the current
        read position of the stream.

        Sets the status of the data stream to

        ConstantDescription
        `ReadCorruptData`.

        This function was introduced in Qt 5.7.

        **See also** **startTransaction** (), **commitTransaction** (), and
        **rollbackTransaction** ().
        """
        ...

    def rollbackTransaction(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#rollbackTransaction

        **[since 5.7] void QDataStream::rollbackTransaction()**

        Reverts a read transaction.

        This function is commonly used to rollback the transaction when an
        incomplete read was detected prior to committing the transaction.

        If called on an inner transaction, reverting is delegated to the
        outermost transaction, and subsequently started inner transactions are
        forced to fail.

        For the outermost transaction, restores the stream data to the point of
        the **startTransaction** () call. If the data stream has read corrupt
        data or any of the inner transactions was aborted, this function aborts
        the transaction.

        If the preceding stream operations were successful, sets the status of
        the data stream to

        ConstantDescription
        `ReadPastEnd`.

        This function was introduced in Qt 5.7.

        **See also** **startTransaction** (), **commitTransaction** (), and
        **abortTransaction** ().
        """
        ...

    def commitTransaction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatastream.html#commitTransaction

        **[since 5.7] bool QDataStream::commitTransaction()**

        Completes a read transaction. Returns `true` if no read errors have
        occurred during the transaction; otherwise returns `false`.

        If called on an inner transaction, committing will be postponed until
        the outermost commitTransaction(), **rollbackTransaction** (), or
        **abortTransaction** () call occurs.

        Otherwise, if the stream status indicates reading past the end of the
        data, this function restores the stream data to the point of the
        **startTransaction** () call. When this situation occurs, you need to
        wait for more data to arrive, after which you start a new transaction.
        If the data stream has read corrupt data or any of the inner
        transactions was aborted, this function aborts the transaction.

        This function was introduced in Qt 5.7.

        **See also** **startTransaction** (), **rollbackTransaction** (), and
        **abortTransaction** ().
        """
        ...

    def startTransaction(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#startTransaction

        **[since 5.7] void QDataStream::startTransaction()**

        Starts a new read transaction on the stream.

        Defines a restorable point within the sequence of read operations. For
        sequential devices, read data will be duplicated internally to allow
        recovery in case of incomplete reads. For random-access devices, this
        function saves the current position of the stream. Call
        **commitTransaction** (), **rollbackTransaction** (), or
        **abortTransaction** () to finish the current transaction.

        Once a transaction is started, subsequent calls to this function will
        make the transaction recursive. Inner transactions act as agents of the
        outermost transaction (i.e., report the status of read operations to the
        outermost transaction, which can restore the position of the stream).

        **Note:** Restoring to the point of the nested startTransaction() call
        is not supported.

        When an error occurs during a transaction (including an inner
        transaction failing), reading from the data stream is suspended (all
        subsequent read operations return empty/zero values) and subsequent
        inner transactions are forced to fail. Starting a new outermost
        transaction recovers from this state. This behavior makes it unnecessary
        to error-check every read operation separately.

        This function was introduced in Qt 5.7.

        **See also** **commitTransaction** (), **rollbackTransaction** (), and
        **abortTransaction** ().
        """
        ...

    def skipRawData(self, len: int) -> int:
        """
        https://doc.qt.io/qt-6/qdatastream.html#skipRawData

        **int QDataStream::skipRawData(int len )**

        Skips **len** bytes from the device. Returns the number of bytes
        actually skipped, or -1 on error.

        This is equivalent to calling **readRawData** () on a buffer of length
        **len** and ignoring the buffer.

        **See also** **QIODevice::seek** ().
        """
        ...

    def writeRawData(self, a0: PyQt6.sip.Buffer) -> int:
        """
        https://doc.qt.io/qt-6/qdatastream.html#writeRawData

        **int QDataStream::writeRawData(const char * s , int len )**

        Writes **len** bytes from **s** to the stream. Returns the number of
        bytes actually written, or -1 on error. The data is **not** encoded.

        **See also** **writeBytes** (), **QIODevice::write** (), and
        **readRawData** ().
        """
        ...

    def writeBytes(self, a0: PyQt6.sip.Buffer) -> "QDataStream":
        """
        https://doc.qt.io/qt-6/qdatastream.html#writeBytes

        **QDataStream &QDataStream::writeBytes(const char * s , uint len )**

        Writes the length specifier **len** and the buffer **s** to the stream
        and returns a reference to the stream.

        The **len** is serialized as a quint32, followed by **len** bytes from
        **s**. Note that the data is **not** encoded.

        **See also** **writeRawData** () and **readBytes** ().
        """
        ...

    def readRawData(self, len: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qdatastream.html#readRawData

        **int QDataStream::readRawData(char * s , int len )**

        Reads at most **len** bytes from the stream into **s** and returns the
        number of bytes read. If an error occurs, this function returns -1.

        The buffer **s** must be preallocated. The data is **not** decoded.

        **See also** **readBytes** (), **QIODevice::read** (), and
        **writeRawData** ().
        """
        ...

    def readBytes(self) -> bytes:
        """
        https://doc.qt.io/qt-6/qdatastream.html#readBytes

        **QDataStream &QDataStream::readBytes(char *& s , uint & l )**

        Reads the buffer **s** from the stream and returns a reference to the
        stream.

        The buffer **s** is allocated using `new []`. Destroy it with the
        `delete []` operator.

        The **l** parameter is set to the length of the buffer. If the string
        read is empty, **l** is set to 0 and **s** is set to `nullptr`.

        The serialization format is a quint32 length specifier first, then **l**
        bytes of data.

        **See also** **readRawData** () and **writeBytes** ().
        """
        ...

    def setVersion(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#setVersion

        **void QDataStream::setVersion(int v )**

        Sets the version number of the data serialization format to **v** , a
        value of the **Version**  enum.

        You don't **have** to set a version if you are using the current version
        of Qt, but for your own custom binary formats we recommend that you do;
        see **Versioning**  in the Detailed Description.

        To accommodate new functionality, the datastream serialization format of
        some Qt classes has changed in some versions of Qt. If you want to read
        data that was created by an earlier version of Qt, or write data that
        can be read by a program that was compiled with an earlier version of
        Qt, use this function to modify the serialization format used by
        **QDataStream** .

        The **Version**  enum provides symbolic constants for the different
        versions of Qt. For example:

        **QDataStream**  out(file);
            out.setVersion(**QDataStream**
        ::Qt_4_0);

        **See also** **version** () and **Version** .
        """
        ...

    def version(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatastream.html#version

        **int QDataStream::version() const**

        Returns the version number of the data serialization format.

        **See also** **setVersion** () and **Version** .
        """
        ...

    def setByteOrder(self, a0: "QDataStream.ByteOrder") -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#setByteOrder

        **void QDataStream::setByteOrder(QDataStream::ByteOrder bo )**

        Sets the serialization byte order to **bo**.

        The **bo** parameter can be **QDataStream::BigEndian**  or
        **QDataStream::LittleEndian** .

        The default setting is big-endian. We recommend leaving this setting
        unless you have special requirements.

        **See also** **byteOrder** ().
        """
        ...

    def byteOrder(self) -> "QDataStream.ByteOrder":
        """
        https://doc.qt.io/qt-6/qdatastream.html#byteOrder

        **QDataStream::ByteOrder QDataStream::byteOrder() const**

        Returns the current byte order setting -- either **BigEndian**  or
        **LittleEndian** .

        **See also** **setByteOrder** ().
        """
        ...

    def setFloatingPointPrecision(
        self, precision: "QDataStream.FloatingPointPrecision"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#setFloatingPointPrecision

        **void QDataStream::setFloatingPointPrecision(QDataStream::FloatingPoint
        Precision precision )**

        Sets the floating point precision of the data stream to **precision**.
        If the floating point precision is **DoublePrecision**  and the version
        of the data stream is **Qt_4_6**  or higher, all floating point numbers
        will be written and read with 64-bit precision. If the floating point
        precision is **SinglePrecision**  and the version is **Qt_4_6**  or
        higher, all floating point numbers will be written and read with 32-bit
        precision.

        For versions prior to **Qt_4_6** , the precision of floating point
        numbers in the data stream depends on the stream operator called.

        The default is **DoublePrecision** .

        Note that this property does not affect the serialization or
        deserialization of `qfloat16` instances.

        **Warning:** This property must be set to the same value on the object
        that writes and the object that reads the data stream.

        **See also** **floatingPointPrecision** ().
        """
        ...

    def floatingPointPrecision(self) -> "QDataStream.FloatingPointPrecision":
        """
        https://doc.qt.io/qt-6/qdatastream.html#floatingPointPrecision

        **QDataStream::FloatingPointPrecision
        QDataStream::floatingPointPrecision() const**

        Returns the floating point precision of the data stream.

        **See also** **FloatingPointPrecision**  and
        **setFloatingPointPrecision** ().
        """
        ...

    def resetStatus(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#resetStatus

        **void QDataStream::resetStatus()**

        Resets the status of the data stream.

        **See also** **Status** , **status** (), and **setStatus** ().
        """
        ...

    def setStatus(self, status: "QDataStream.Status") -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#setStatus

        **void QDataStream::setStatus(QDataStream::Status status )**

        Sets the status of the data stream to the **status** given.

        Subsequent calls to setStatus() are ignored until **resetStatus** () is
        called.

        **See also** **Status** , **status** (), and **resetStatus** ().
        """
        ...

    def status(self) -> "QDataStream.Status":
        """
        https://doc.qt.io/qt-6/qdatastream.html#status

        **QDataStream::Status QDataStream::status() const**

        Returns the status of the data stream.

        **See also** **Status** , **setStatus** (), and **resetStatus** ().
        """
        ...

    def atEnd(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatastream.html#atEnd

        **bool QDataStream::atEnd() const**

        Returns `true` if the I/O device has reached the end position (end of
        the stream or file) or if there is no I/O device set; otherwise returns
        `false`.

        **See also** **QIODevice::atEnd** ().
        """
        ...

    def setDevice(self, a0: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qdatastream.html#setDevice

        **void QDataStream::setDevice(QIODevice * d )**

        void QDataStream::setDevice(**QIODevice**  *d)

        Sets the I/O device to **d** , which can be `nullptr` to unset to
        current I/O device.

        **See also** **device** ().
        """
        ...

    def device(self) -> QIODevice:
        """
        https://doc.qt.io/qt-6/qdatastream.html#device

        **QIODevice *QDataStream::device() const**

        Returns the I/O device currently set, or `nullptr` if no device is
        currently set.

        **See also** **setDevice** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *


class QLowEnergyDescriptor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergydescriptor.html

    **Detailed Description**

    QLowEnergyDescriptor provides information about a Bluetooth Low Energy
    descriptor's **name** (), **uuid** (), and **value** (). Descriptors are
    encapsulated by Bluetooth Low Energy characteristics and provide additional
    contextual information about the characteristic (data format, notification
    activation and so on).

    The descriptor value may be written via the **QLowEnergyService**  instance
    that manages the service to which this descriptor belongs. The
    **QLowEnergyService::writeDescriptor** () function writes the new value. The
    **QLowEnergyService::descriptorWritten** () signal is emitted upon success.
    The cached **value** () of this object is updated accordingly.

    **See also** **QLowEnergyService**  and **QLowEnergyCharacteristic** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#QLowEnergyDescriptor

        **QLowEnergyDescriptor::QLowEnergyDescriptor()**

        Construct a new QLowEnergyDescriptor. A default-constructed instance of
        this class is always invalid.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyDescriptor") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#QLowEnergyDescriptor-1

        **QLowEnergyDescriptor::QLowEnergyDescriptor(const QLowEnergyDescriptor
        & other )**

        Construct a new QLowEnergyDescriptor that is a copy of **other**.

        The two copies continue to share the same underlying data which does not
        detach upon write.
        """
        ...

    def type(self) -> QBluetoothUuid.DescriptorType:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#type

        **QBluetoothUuid::DescriptorType QLowEnergyDescriptor::type() const**

        Returns the type of the descriptor.

        **See also** **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#name

        **QString QLowEnergyDescriptor::name() const**

        Returns the human-readable name of the descriptor.

        The name is based on the descriptor's **type** (). The complete list of
        descriptor types can be found under **Bluetooth.org Descriptors** .

        The returned string is empty if the **type** () is unknown.

        **See also** **type** () and **QBluetoothUuid::descriptorToString** ().
        """
        ...

    def uuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#uuid

        **QBluetoothUuid QLowEnergyDescriptor::uuid() const**

        Returns the UUID of this descriptor if **isValid** () returns `true`;
        otherwise a **null**  UUID.
        """
        ...

    def value(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#value

        **QByteArray QLowEnergyDescriptor::value() const**

        Returns the cached value of the descriptor.

        The cached descriptor value may be updated using
        **QLowEnergyService::writeDescriptor** () or
        **QLowEnergyService::readDescriptor** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergydescriptor.html#isValid

        **bool QLowEnergyDescriptor::isValid() const**

        Returns `true` if the **QLowEnergyDescriptor**  object is valid,
        otherwise returns `false`.

        An invalid descriptor instance is not associated with any service
        (default-constructed) or the associated service is no longer valid due
        to a disconnect from the underlying Bluetooth Low Energy device, for
        example. Once the object is invalid it cannot become valid anymore.

        **Note:** If a **QLowEnergyDescriptor**  instance turns invalid due to a
        disconnect from the underlying device, the information encapsulated by
        the current instance remains as it was at the time of the disconnect.
        Therefore it can be retrieved after the disconnect event.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QSignalMapper(QObject):
    """
    https://doc.qt.io/qt-6/qsignalmapper.html

    **Detailed Description**

    This class collects a set of parameterless signals, and re-emits them with
    integer, string or widget parameters corresponding to the object that sent
    the signal. Note that in most cases you can use lambdas for passing custom
    parameters to slots. This is less costly and will simplify the code.

    The class supports the mapping of particular strings, integers, objects and
    widgets with particular objects using **setMapping** (). The objects'
    signals can then be connected to the **map** () slot which will emit a
    signal (it could be **mappedInt** (), **mappedString** () and
    **mappedObject** ()) with a value associated with the original signalling
    object. Mappings can be removed later using **removeMappings** ().

    Example: Suppose we want to create a custom widget that contains a group of
    buttons (like a tool palette). One approach is to connect each button's
    `clicked()` signal to its own custom slot; but in this example we want to
    connect all the buttons to a single slot and parameterize the slot by the
    button that was clicked.

    Here's the definition of a simple custom widget that has a single signal,
    `clicked()`, which is emitted with the text of the button that was clicked:

    class ButtonWidget : public **QWidget**
        {
            Q_OBJECT
    public:
            ButtonWidget(const **QStringList**  &texts, **QWidget**
    *parent = nullptr);

        signals:
            void clicked(const **QString**
    &text);

        private:
            **QSignalMapper**  *signalMapper;
        };

    The only function that we need to implement is the constructor:

    ButtonWidget::ButtonWidget(const **QStringList**  &texts, **QWidget**
    *parent)
            : **QWidget** (parent)
        {
            signalMapper = new
    **QSignalMapper** (this);

            **QGridLayout**  *gridLayout = new
    **QGridLayout** ;
            for (int i = 0; i < texts.size(); ++i) {
    **QPushButton**  *button = new **QPushButton** (texts[i]);
    connect(button, &**QPushButton** ::clicked, signalMapper, &**QSignalMapper**
    ::map);
                signalMapper->setMapping(button, texts[i]);
    gridLayout->addWidget(button, i / 3, i % 3);
            }
    connect(signalMapper, &**QSignalMapper** ::mappedString,
    this, &ButtonWidget::clicked);

            setLayout(gridLayout);
        }

    A list of texts is passed to the constructor. A signal mapper is constructed
    and for each text in the list a **QPushButton**  is created. We connect each
    button's `clicked()` signal to the signal mapper's **map** () slot, and
    create a mapping in the signal mapper from each button to the button's text.
    Finally we connect the signal mapper's **mappedString** () signal to the
    custom widget's `clicked()` signal. When the user clicks a button, the
    custom widget will emit a single `clicked()` signal whose argument is the
    text of the button the user clicked.

    This class was mostly useful before lambda functions could be used as slots.
    The example above can be rewritten simpler without QSignalMapper by
    connecting to a lambda function.

    ButtonWidget::ButtonWidget(const **QStringList**  &texts, **QWidget**
    *parent)
            : **QWidget** (parent)
        {
            **QGridLayout**
    *gridLayout = new **QGridLayout** ;
            for (int i = 0; i <
    texts.size(); ++i) {
                **QString**  text = texts[i];
    **QPushButton**  *button = new **QPushButton** (text);
    connect(button, &**QPushButton** ::clicked, [this, text] { clicked(text);
    });
                gridLayout->addWidget(button, i / 3, i % 3);
            }
    setLayout(gridLayout);
        }

    **See also** **QObject** , **QButtonGroup** , and **QActionGroup** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#QSignalMapper

        **QSignalMapper::QSignalMapper(QObject * parent = nullptr)**

        Constructs a QSignalMapper with parent **parent**.
        """
        ...

    @typing.overload
    def map(self) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#map

        **[slot] void QSignalMapper::map()**

        This slot emits signals based on which object sends signals to it.
        """
        ...

    @typing.overload
    def map(self, sender: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#map-1

        **[slot] void QSignalMapper::map(QObject * sender )**

        This slot emits signals based on the **sender** object.
        """
        ...

    @typing.overload
    def mapping(self, id: int) -> QObject:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#mapping

        **QObject *QSignalMapper::mapping(int id ) const**

        Returns the sender **QObject**  that is associated with the **id**.

        **See also** **setMapping** ().
        """
        ...

    @typing.overload
    def mapping(self, text: str) -> QObject:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#mapping-1

        **QObject *QSignalMapper::mapping(const QString & id ) const**

        This function overloads mapping().
        """
        ...

    @typing.overload
    def mapping(self, object: QObject) -> QObject:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#mapping-2

        **QObject *QSignalMapper::mapping(QObject * object ) const**

        This function overloads mapping().

        Returns the sender **QObject**  that is associated with the **object**.
        """
        ...

    def removeMappings(self, sender: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#removeMappings

        **void QSignalMapper::removeMappings(QObject * sender )**

        Removes all mappings for **sender**.

        This is done automatically when mapped objects are destroyed.

        **Note:** This does not disconnect any signals. If **sender** is not
        destroyed then this will need to be done explicitly if required.
        """
        ...

    @typing.overload
    def setMapping(self, sender: QObject, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#setMapping

        **void QSignalMapper::setMapping(QObject * sender , int id )**

        Adds a mapping so that when **map** () is signalled from the given
        **sender** , the signal **mappedInt** ( **id** ) is emitted.

        There may be at most one integer ID for each sender.

        **See also** **mapping** ().
        """
        ...

    @typing.overload
    def setMapping(self, sender: QObject, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#setMapping-1

        **void QSignalMapper::setMapping(QObject * sender , const QString & text
        )**

        Adds a mapping so that when **map** () is signalled from the **sender**
        , the signal **mappedString** ( **text** ) is emitted.

        There may be at most one text for each sender.
        """
        ...

    @typing.overload
    def setMapping(self, sender: QObject, object: QObject) -> None:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#setMapping-2

        **void QSignalMapper::setMapping(QObject * sender , QObject * object )**

        Adds a mapping so that when **map** () is signalled from the **sender**
        , the signal **mappedObject** ( **object** ) is emitted.

        There may be at most one object for each sender.
        """
        ...

    @property
    def mappedInt(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#mappedInt

        **[signal, since 5.15] void QSignalMapper::mappedInt(int i )**

        This signal is emitted when **map** () is signalled from an object that
        has an integer mapping set. The object's mapped integer is passed in
        **i**.

        This function was introduced in Qt 5.15.

        **See also** **setMapping** ().
        """
        ...

    @property
    def mappedObject(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#mappedObject

        **[signal, since 5.15] void QSignalMapper::mappedObject(QObject * object
        )**

        This signal is emitted when **map** () is signalled from an object that
        has an object mapping set. The object provided by the map is passed in
        **object**.

        This function was introduced in Qt 5.15.

        **See also** **setMapping** ().
        """
        ...

    @property
    def mappedString(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsignalmapper.html#mappedString

        **[signal, since 5.15] void QSignalMapper::mappedString(const QString &
        text )**

        This signal is emitted when **map** () is signalled from an object that
        has a string mapping set. The object's mapped string is passed in
        **text**.

        This function was introduced in Qt 5.15.

        **See also** **setMapping** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMetaClassInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmetaclassinfo.html

    **Detailed Description**

    Class information items are simple **name** \\-- **value** pairs that are
    specified using **Q_CLASSINFO** () in the source code. The information can
    be retrieved using **name** () and **value** (). For example:

    class MyClass
        {
            Q_OBJECT
            Q_CLASSINFO("author", "Sabrina
    Schweinsteiger")
            Q_CLASSINFO("url",
    "http://doc.moosesoft.co.uk/1.0/")

        public:
            ...
        };

    This mechanism is free for you to use in your Qt applications. Qt doesn't
    use it for any of its classes.

    **See also** **QMetaObject** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QMetaClassInfo") -> None:
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaclassinfo.html#value

        **const char *QMetaClassInfo::value() const**

        Returns the value of this item.

        **See also** **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaclassinfo.html#name

        **const char *QMetaClassInfo::name() const**

        Returns the name of this item.

        **See also** **value** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QAbstractSlider(QWidget):
    """
    https://doc.qt.io/qt-6/qabstractslider.html

    **Detailed Description**

    The class is designed as a common super class for widgets like
    **QScrollBar** , **QSlider**  and **QDial** .

    Here are the main properties of the class:

    1. **value** : The bounded integer that QAbstractSlider maintains.
      2.
    **minimum** : The lowest possible value.
      3. **maximum** : The highest
    possible value.
      4. **singleStep** : The smaller of two natural steps that
    an abstract sliders provides and typically corresponds to the user pressing
    an arrow key.
      5. **pageStep** : The larger of two natural steps that an
    abstract slider provides and typically corresponds to the user pressing
    PageUp or PageDown.
      6. **tracking** : Whether slider tracking is enabled.
    7. **sliderPosition** : The current position of the slider. If **tracking**
    is enabled (the default), this is identical to **value** .

    Unity (1) may be viewed as a third step size. **setValue** () lets you set
    the current value to any integer in the allowed range, not just **minimum**
    () + **n** * **singleStep** () for integer values of **n**. Some widgets may
    allow the user to set any value at all; others may just provide multiples of
    **singleStep** () or **pageStep** ().

    QAbstractSlider emits a comprehensive set of signals:

    SignalEmitted when
    **valueChanged** ()the value has changed. The
    **tracking**  determines whether this signal is emitted during user
    interaction.
    **sliderPressed** ()the user starts to drag the slider.
    **sliderMoved** ()the user drags the slider.
    **sliderReleased** ()the user
    releases the slider.
    **actionTriggered** ()a slider action was triggered.
    **rangeChanged** ()a the range has changed.

    QAbstractSlider provides a virtual **sliderChange** () function that is well
    suited for updating the on-screen representation of sliders. By calling
    **triggerAction** (), subclasses trigger slider actions. Two helper
    functions **QStyle::sliderPositionFromValue** () and
    **QStyle::sliderValueFromPosition** () help subclasses and styles to map
    screen coordinates to logical range values.

    **See also** **QAbstractSpinBox** , **QSlider** , **QDial** , **QScrollBar**
    , and **Sliders Example** .
    """

    class SliderChange(enum.Enum):
        SliderRangeChange: QAbstractSlider = ...
        SliderOrientationChange: QAbstractSlider = ...
        SliderStepsChange: QAbstractSlider = ...
        SliderValueChange: QAbstractSlider = ...

    class SliderAction(enum.Enum):
        SliderNoAction: QAbstractSlider = ...
        SliderSingleStepAdd: QAbstractSlider = ...
        SliderSingleStepSub: QAbstractSlider = ...
        SliderPageStepAdd: QAbstractSlider = ...
        SliderPageStepSub: QAbstractSlider = ...
        SliderToMinimum: QAbstractSlider = ...
        SliderToMaximum: QAbstractSlider = ...
        SliderMove: QAbstractSlider = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#QAbstractSlider

        **QAbstractSlider::QAbstractSlider(QWidget * parent = nullptr)**

        Constructs an abstract slider.

        The **parent** argument is sent to the **QWidget**  constructor.

        The **minimum**  defaults to 0, the **maximum**  to 99, with a
        **singleStep**  size of 1 and a **pageStep**  size of 10, and an initial
        **value**  of 0.
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#changeEvent

        **[override virtual protected] void QAbstractSlider::changeEvent(QEvent
        * ev )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#wheelEvent

        **[override virtual protected] void
        QAbstractSlider::wheelEvent(QWheelEvent * e )**

        Reimplements: **QWidget::wheelEvent** (QWheelEvent *event).
        """
        ...

    def timerEvent(self, a0: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#timerEvent

        **[override virtual protected] void
        QAbstractSlider::timerEvent(QTimerEvent * e )**

        Reimplements: **QObject::timerEvent** (QTimerEvent *event).
        """
        ...

    def keyPressEvent(self, ev: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#keyPressEvent

        **[override virtual protected] void
        QAbstractSlider::keyPressEvent(QKeyEvent * ev )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#event

        **[override virtual protected] bool QAbstractSlider::event(QEvent * e
        )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def sliderChange(self, change: "QAbstractSlider.SliderChange") -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderChange

        **[virtual protected] void
        QAbstractSlider::sliderChange(QAbstractSlider::SliderChange change )**

        Reimplement this virtual function to track slider changes such as
        **SliderRangeChange** , **SliderOrientationChange** ,
        **SliderStepsChange** , or **SliderValueChange** . The default
        implementation only updates the display and ignores the **change**
        parameter.
        """
        ...

    def repeatAction(self) -> "QAbstractSlider.SliderAction":
        """
        https://doc.qt.io/qt-6/qabstractslider.html#repeatAction

        **[protected] QAbstractSlider::SliderAction
        QAbstractSlider::repeatAction() const**

        Returns the current repeat action.

        **See also** **setRepeatAction** ().
        """
        ...

    def setRepeatAction(
        self,
        action: "QAbstractSlider.SliderAction",
        thresholdTime: int = ...,
        repeatTime: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#setRepeatAction

        **[protected] void
        QAbstractSlider::setRepeatAction(QAbstractSlider::SliderAction action ,
        int thresholdTime = 500, int repeatTime = 50)**

        Sets action **action** to be triggered repetitively in intervals of
        **repeatTime** , after an initial delay of **thresholdTime**.

        **See also** **triggerAction** () and **repeatAction** ().
        """
        ...

    def setOrientation(self, a0: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the slider

        The orientation must be **Qt::Vertical**  (the default) or
        **Qt::Horizontal** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation)
        """
        ...

    def setValue(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#value-prop

        **value : int**

        This property holds the slider's current value

        The slider forces the value to be within the legal range: **minimum**
        <= `value` <= **maximum** .

        Changing the value also changes the **sliderPosition** .

        **Access functions:**

        int **value** () const
        void **setValue** (int)

        **Notifier signal:**

        void ****valueChanged** ** (int **value** )

        **Member Function Documentation**
        """
        ...

    def triggerAction(self, action: "QAbstractSlider.SliderAction") -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#triggerAction

        **void QAbstractSlider::triggerAction(QAbstractSlider::SliderAction
        action )**

        Triggers a slider **action**. Possible actions are
        **SliderSingleStepAdd** , **SliderSingleStepSub** ,
        **SliderPageStepAdd** , **SliderPageStepSub** , **SliderToMinimum** ,
        **SliderToMaximum** , and **SliderMove** .

        **See also** **actionTriggered** ().
        """
        ...

    def value(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#value-prop

        **value : int**

        This property holds the slider's current value

        The slider forces the value to be within the legal range: **minimum**
        <= `value` <= **maximum** .

        Changing the value also changes the **sliderPosition** .

        **Access functions:**

        int **value** () const
        void **setValue** (int)

        **Notifier signal:**

        void ****valueChanged** ** (int **value** )

        **Member Function Documentation**
        """
        ...

    def invertedControls(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#invertedControls-prop

        **invertedControls : bool**

        This property holds whether or not the slider inverts its wheel and key
        events.

        If this property is `false`, scrolling the mouse wheel "up" and using
        keys like page up will increase the slider's value towards its maximum.
        Otherwise pressing page up will move value towards the slider's minimum.

        **Access functions:**

        bool **invertedControls** () const
        void **setInvertedControls** (bool)
        """
        ...

    def setInvertedControls(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#invertedControls-prop

        **invertedControls : bool**

        This property holds whether or not the slider inverts its wheel and key
        events.

        If this property is `false`, scrolling the mouse wheel "up" and using
        keys like page up will increase the slider's value towards its maximum.
        Otherwise pressing page up will move value towards the slider's minimum.

        **Access functions:**

        bool **invertedControls** () const
        void **setInvertedControls** (bool)
        """
        ...

    def invertedAppearance(self) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#invertedAppearance-prop

        **invertedAppearance : bool**

        This property holds whether or not a slider shows its values inverted.

        If this property is `false` (the default), the minimum and maximum will
        be shown in its classic position for the inherited widget. If the value
        is true, the minimum and maximum appear at their opposite location.

        Note: This property makes most sense for sliders and dials. For scroll
        bars, the visual effect of the scroll bar subcontrols depends on whether
        or not the styles understand inverted appearance; most styles ignore
        this property for scroll bars.

        **Access functions:**

        bool **invertedAppearance** () const
        void **setInvertedAppearance**
        (bool)
        """
        ...

    def setInvertedAppearance(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#invertedAppearance-prop

        **invertedAppearance : bool**

        This property holds whether or not a slider shows its values inverted.

        If this property is `false` (the default), the minimum and maximum will
        be shown in its classic position for the inherited widget. If the value
        is true, the minimum and maximum appear at their opposite location.

        Note: This property makes most sense for sliders and dials. For scroll
        bars, the visual effect of the scroll bar subcontrols depends on whether
        or not the styles understand inverted appearance; most styles ignore
        this property for scroll bars.

        **Access functions:**

        bool **invertedAppearance** () const
        void **setInvertedAppearance**
        (bool)
        """
        ...

    def sliderPosition(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderPosition-prop

        **sliderPosition : int**

        This property holds the current slider position

        If **tracking**  is enabled (the default), this is identical to
        **value** .

        **Access functions:**

        int **sliderPosition** () const
        void **setSliderPosition** (int)

        **Notifier signal:**

        void ****sliderMoved** ** (int **value** )
        """
        ...

    def setSliderPosition(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderPosition-prop

        **sliderPosition : int**

        This property holds the current slider position

        If **tracking**  is enabled (the default), this is identical to
        **value** .

        **Access functions:**

        int **sliderPosition** () const
        void **setSliderPosition** (int)

        **Notifier signal:**

        void ****sliderMoved** ** (int **value** )
        """
        ...

    def isSliderDown(self) -> bool:
        ...

    def setSliderDown(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderDown-prop

        **sliderDown : bool**

        This property holds whether the slider is pressed down.

        The property is set by subclasses in order to let the abstract slider
        know whether or not **tracking**  has any effect.

        Changing the slider down property emits the **sliderPressed** () and
        **sliderReleased** () signals.

        **Access functions:**

        bool **isSliderDown** () const
        void **setSliderDown** (bool)
        """
        ...

    def hasTracking(self) -> bool:
        ...

    def setTracking(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#tracking-prop

        **tracking : bool**

        This property holds whether slider tracking is enabled

        If tracking is enabled (the default), the slider emits the
        **valueChanged** () signal while the slider is being dragged. If
        tracking is disabled, the slider emits the **valueChanged** () signal
        only when the user releases the slider.

        **Access functions:**

        bool **hasTracking** () const
        void **setTracking** (bool **enable** )

        **See also** **sliderDown** .
        """
        ...

    def pageStep(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#pageStep-prop

        **pageStep : int**

        This property holds the page step.

        The larger of two natural steps that an abstract slider provides and
        typically corresponds to the user pressing PageUp or PageDown.

        **Access functions:**

        int **pageStep** () const
        void **setPageStep** (int)

        **See also** **singleStep** .
        """
        ...

    def setPageStep(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#pageStep-prop

        **pageStep : int**

        This property holds the page step.

        The larger of two natural steps that an abstract slider provides and
        typically corresponds to the user pressing PageUp or PageDown.

        **Access functions:**

        int **pageStep** () const
        void **setPageStep** (int)

        **See also** **singleStep** .
        """
        ...

    def singleStep(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#singleStep-prop

        **singleStep : int**

        This property holds the single step.

        The smaller of two natural steps that an abstract sliders provides and
        typically corresponds to the user pressing an arrow key.

        If the property is modified during an auto repeating key event, behavior
        is undefined.

        **Access functions:**

        int **singleStep** () const
        void **setSingleStep** (int)

        **See also** **pageStep** .
        """
        ...

    def setSingleStep(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#singleStep-prop

        **singleStep : int**

        This property holds the single step.

        The smaller of two natural steps that an abstract sliders provides and
        typically corresponds to the user pressing an arrow key.

        If the property is modified during an auto repeating key event, behavior
        is undefined.

        **Access functions:**

        int **singleStep** () const
        void **setSingleStep** (int)

        **See also** **pageStep** .
        """
        ...

    def setRange(self, min: int, max: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#setRange

        **[slot] void QAbstractSlider::setRange(int min , int max )**

        Sets the slider's minimum to **min** and its maximum to **max**.

        If **max** is smaller than **min** , **min** becomes the only legal
        value.

        **See also** **minimum**  and **maximum** .
        """
        ...

    def maximum(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#maximum-prop

        **maximum : int**

        This property holds the slider's maximum value

        When setting this property, the **minimum**  is adjusted if necessary to
        ensure that the range remains valid. Also the slider's current value is
        adjusted to be within the new range.

        **Access functions:**

        int **maximum** () const
        void **setMaximum** (int)
        """
        ...

    def setMaximum(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#maximum-prop

        **maximum : int**

        This property holds the slider's maximum value

        When setting this property, the **minimum**  is adjusted if necessary to
        ensure that the range remains valid. Also the slider's current value is
        adjusted to be within the new range.

        **Access functions:**

        int **maximum** () const
        void **setMaximum** (int)
        """
        ...

    def minimum(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#minimum-prop

        **minimum : int**

        This property holds the sliders's minimum value

        When setting this property, the **maximum**  is adjusted if necessary to
        ensure that the range remains valid. Also the slider's current value is
        adjusted to be within the new range.

        **Access functions:**

        int **minimum** () const
        void **setMinimum** (int)
        """
        ...

    def setMinimum(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#minimum-prop

        **minimum : int**

        This property holds the sliders's minimum value

        When setting this property, the **maximum**  is adjusted if necessary to
        ensure that the range remains valid. Also the slider's current value is
        adjusted to be within the new range.

        **Access functions:**

        int **minimum** () const
        void **setMinimum** (int)
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the slider

        The orientation must be **Qt::Vertical**  (the default) or
        **Qt::Horizontal** .

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation)
        """
        ...

    @property
    def actionTriggered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#actionTriggered

        **[signal] void QAbstractSlider::actionTriggered(int action )**

        This signal is emitted when the slider action **action** is triggered.
        Actions are **SliderSingleStepAdd** , **SliderSingleStepSub** ,
        **SliderPageStepAdd** , **SliderPageStepSub** , **SliderToMinimum** ,
        **SliderToMaximum** , and **SliderMove** .

        When the signal is emitted, the **sliderPosition**  has been adjusted
        according to the action, but the **value**  has not yet been propagated
        (meaning the **valueChanged** () signal was not yet emitted), and the
        visual display has not been updated. In slots connected to this signal
        you can thus safely adjust any action by calling **setSliderPosition**
        () yourself, based on both the action and the slider's value.

        **See also** **triggerAction** ().
        """
        ...

    @property
    def rangeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#rangeChanged

        **[signal] void QAbstractSlider::rangeChanged(int min , int max )**

        This signal is emitted when the slider range has changed, with **min**
        being the new minimum, and **max** being the new maximum.

        **See also** **minimum**  and **maximum** .
        """
        ...

    @property
    def sliderMoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderMoved

        **[signal] void QAbstractSlider::sliderMoved(int value )**

        This signal is emitted when **sliderDown**  is true and the slider
        moves. This usually happens when the user is dragging the slider. The
        **value** is the new slider position.

        This signal is emitted even when tracking is turned off.

        **Note:** Notifier signal for property **sliderPosition** .

        **See also** **setTracking** (), **valueChanged** (), **isSliderDown**
        (), **sliderPressed** (), and **sliderReleased** ().
        """
        ...

    @property
    def sliderPressed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderPressed

        **[signal] void QAbstractSlider::sliderPressed()**

        This signal is emitted when the user presses the slider with the mouse,
        or programmatically when **setSliderDown** (true) is called.

        **See also** **sliderReleased** (), **sliderMoved** (), and
        **isSliderDown** ().
        """
        ...

    @property
    def sliderReleased(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#sliderReleased

        **[signal] void QAbstractSlider::sliderReleased()**

        This signal is emitted when the user releases the slider with the mouse,
        or programmatically when **setSliderDown** (false) is called.

        **See also** **sliderPressed** (), **sliderMoved** (), and
        **sliderDown** .
        """
        ...

    @property
    def valueChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstractslider.html#valueChanged

        **[signal] void QAbstractSlider::valueChanged(int value )**

        This signal is emitted when the slider value has changed, with the new
        slider **value** as argument.

        **Note:** Notifier signal for property **value** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QStylePainter(QtGui.QPainter):
    """
    https://doc.qt.io/qt-6/qstylepainter.html

    **Detailed Description**

    QStylePainter extends **QPainter**  with a set of high-level `draw...()`
    functions implemented on top of **QStyle** 's API. The advantage of using
    QStylePainter is that the parameter lists get considerably shorter. Whereas
    a **QStyle**  object must be able to draw on any widget using any painter
    (because the application normally has one **QStyle**  object shared by all
    widget), a QStylePainter is initialized with a widget, eliminating the need
    to specify the **QWidget** , the **QPainter** , and the **QStyle**  for
    every function call.

    Example using **QStyle**  directly:

    void MyWidget::paintEvent(**QPaintEvent**  * /* event */)
        {
    **QPainter**  painter(this);

            **QStyleOptionFocusRect**  option;
    option.initFrom(this);
            option.backgroundColor =
    palette().color(**QPalette** ::Background);
    style()->drawPrimitive(**QStyle** ::PE_FrameFocusRect, &option, &painter,
    this);
        }

    Example using QStylePainter:

    void MyWidget::paintEvent(**QPaintEvent**  * /* event */)
        {
    **QStylePainter**  painter(this);

            **QStyleOptionFocusRect**
    option;
            option.initFrom(this);
            option.backgroundColor =
    palette().color(**QPalette** ::Background);
    painter.drawPrimitive(**QStyle** ::PE_FrameFocusRect, option);
        }

    **See also** **QStyle**  and **QStyleOption** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#QStylePainter

        **QStylePainter::QStylePainter()**

        Constructs a QStylePainter.
        """
        ...

    @typing.overload
    def __init__(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#QStylePainter-1

        **QStylePainter::QStylePainter(QWidget * widget )**

        Construct a QStylePainter using widget **widget** for its paint device.
        """
        ...

    @typing.overload
    def __init__(self, pd: QtGui.QPaintDevice, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#QStylePainter-2

        **QStylePainter::QStylePainter(QPaintDevice * pd , QWidget * widget )**

        Construct a QStylePainter using **pd** for its paint device, and
        attributes from **widget**.
        """
        ...

    def drawItemPixmap(
        self, r: QtCore.QRect, flags: int, pixmap: QtGui.QPixmap
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#drawItemPixmap

        **void QStylePainter::drawItemPixmap(const QRect & rect , int flags ,
        const QPixmap & pixmap )**

        Draws the **pixmap** in rectangle **rect**. The pixmap is aligned
        according to **flags**.

        **See also** **QStyle::drawItemPixmap** () and **Qt::Alignment** .
        """
        ...

    def drawItemText(
        self,
        rect: QtCore.QRect,
        flags: int,
        pal: QtGui.QPalette,
        enabled: bool,
        text: str,
        textRole: QtGui.QPalette.ColorRole = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#drawItemText

        **void QStylePainter::drawItemText(const QRect & rect , int flags ,
        const QPalette & pal , bool enabled , const QString & text ,
        QPalette::ColorRole textRole = QPalette::NoRole)**

        Draws the **text** in rectangle **rect** and palette **pal**. The text
        is aligned and wrapped according to **flags**.

        The pen color is specified with **textRole**. The **enabled** bool
        indicates whether or not the item is enabled; when reimplementing this
        bool should influence how the item is drawn.

        **See also** **QStyle::drawItemText** () and **Qt::Alignment** .
        """
        ...

    def drawComplexControl(
        self, cc: QStyle.ComplexControl, opt: QStyleOptionComplex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#drawComplexControl

        **void QStylePainter::drawComplexControl(QStyle::ComplexControl cc ,
        const QStyleOptionComplex & option )**

        Use the widget's style to draw a complex control **cc** specified by the
        **QStyleOptionComplex**  **option**.

        **See also** **QStyle::drawComplexControl** ().
        """
        ...

    def drawControl(self, ce: QStyle.ControlElement, opt: QStyleOption) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#drawControl

        **void QStylePainter::drawControl(QStyle::ControlElement ce , const
        QStyleOption & option )**

        Use the widget's style to draw a control element **ce** specified by
        **QStyleOption**  **option**.

        **See also** **QStyle::drawControl** ().
        """
        ...

    def drawPrimitive(self, pe: QStyle.PrimitiveElement, opt: QStyleOption) -> None:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#drawPrimitive

        **void QStylePainter::drawPrimitive(QStyle::PrimitiveElement pe , const
        QStyleOption & option )**

        Use the widget's style to draw a primitive element **pe** specified by
        **QStyleOption**  **option**.

        **See also** **QStyle::drawPrimitive** ().
        """
        ...

    def style(self) -> QStyle:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#style

        **QStyle *QStylePainter::style() const**

        Return the current style used by the **QStylePainter** .
        """
        ...

    @typing.overload
    def begin(self, w: QWidget) -> bool:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#begin

        **bool QStylePainter::begin(QWidget * widget )**

        Begin painting operations on the specified **widget**. Returns `true` if
        the painter is ready to use; otherwise returns `false`.

        This is automatically called by the constructor that takes a **QWidget**
        .
        """
        ...

    @typing.overload
    def begin(self, pd: QtGui.QPaintDevice, w: QWidget) -> bool:
        """
        https://doc.qt.io/qt-6/qstylepainter.html#begin-1

        **bool QStylePainter::begin(QPaintDevice * pd , QWidget * widget )**

        This is an overloaded function.

        Begin painting operations on paint device **pd** as if it was
        **widget**.

        This is automatically called by the constructor that takes a
        **QPaintDevice**  and a **QWidget** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QPolygonF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpolygonf.html

    **Detailed Description**

    A QPolygonF is a **QList** <**QPointF** >. The easiest way to add points to
    a QPolygonF is to use its streaming operator, as illustrated below:

    **QPolygonF**  polygon;
        polygon << **QPointF** (10.4, 20.5) <<
    **QPointF** (20.2, 30.2);

    In addition to the functions provided by **QList** , QPolygonF provides the
    **boundingRect** () and **translate** () functions for geometry operations.
    Use the **QTransform::map** () function for more general transformations of
    QPolygonFs.

    QPolygonF also provides the **isClosed** () function to determine whether a
    polygon's start and end points are the same, and the **toPolygon** ()
    function returning an integer precision copy of this polygon.

    The QPolygonF class is **implicitly shared** .

    **See also** **QList** , **QPolygon** , and **QLineF** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#QPolygonF

        **QPolygonF::QPolygonF()**

        Constructs a polygon with no points.

        **See also** **QList::isEmpty** ().
        """
        ...

    @typing.overload
    def __init__(self, v: typing.Iterable[QtCore.QPointF]) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#QPolygonF-1

        **QPolygonF::QPolygonF(const QList<QPointF> & points )**

        Constructs a polygon containing the specified **points**.
        """
        ...

    @typing.overload
    def __init__(self, r: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#QPolygonF-3

        **QPolygonF::QPolygonF(const QRectF & rectangle )**

        Constructs a closed polygon from the specified **rectangle**.

        The polygon contains the four vertices of the rectangle in clockwise
        order starting and ending with the top-left vertex.

        **See also** **isClosed** ().
        """
        ...

    @typing.overload
    def __init__(self, a: QPolygon) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#QPolygonF-4

        **QPolygonF::QPolygonF(const QPolygon & polygon )**

        Constructs a float based polygon from the specified integer based
        **polygon**.

        **See also** **toPolygon** ().
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#QPolygonF

        **QPolygonF::QPolygonF()**

        Constructs a polygon with no points.

        **See also** **QList::isEmpty** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QPolygonF") -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#QPolygonF

        **QPolygonF::QPolygonF()**

        Constructs a polygon with no points.

        **See also** **QList::isEmpty** ().
        """
        ...

    def __contains__(self, value: QtCore.QPointF) -> int:
        ...

    @typing.overload
    def __delitem__(self, i: int) -> None:
        ...

    @typing.overload
    def __delitem__(self, slice: slice) -> None:
        ...

    @typing.overload
    def __setitem__(self, i: int, value: QtCore.QPointF) -> None:
        ...

    @typing.overload
    def __setitem__(self, slice: slice, list: "QPolygonF") -> None:
        ...

    @typing.overload
    def __getitem__(self, i: int) -> QtCore.QPointF:
        ...

    @typing.overload
    def __getitem__(self, slice: slice) -> "QPolygonF":
        ...

    @typing.overload
    def value(self, i: int) -> QtCore.QPointF:
        ...

    @typing.overload
    def value(self, i: int, defaultValue: QtCore.QPointF) -> QtCore.QPointF:
        ...

    def size(self) -> int:
        ...

    def replace(self, i: int, value: QtCore.QPointF) -> None:
        ...

    @typing.overload
    def remove(self, i: int) -> None:
        ...

    @typing.overload
    def remove(self, i: int, count: int) -> None:
        ...

    def prepend(self, value: QtCore.QPointF) -> None:
        ...

    def mid(self, pos: int, length: int = ...) -> "QPolygonF":
        ...

    def lastIndexOf(self, value: QtCore.QPointF, from_: int = ...) -> int:
        ...

    def last(self) -> QtCore.QPointF:
        ...

    def isEmpty(self) -> bool:
        ...

    def insert(self, i: int, value: QtCore.QPointF) -> None:
        ...

    def indexOf(self, value: QtCore.QPointF, from_: int = ...) -> int:
        ...

    def first(self) -> QtCore.QPointF:
        ...

    def fill(self, value: QtCore.QPointF, size: int = ...) -> None:
        ...

    def data(self) -> PyQt6.sip.voidptr:
        ...

    def __len__(self) -> int:
        ...

    @typing.overload
    def count(self, value: QtCore.QPointF) -> int:
        ...

    @typing.overload
    def count(self) -> int:
        ...

    def contains(self, value: QtCore.QPointF) -> bool:
        ...

    def clear(self) -> None:
        ...

    def at(self, i: int) -> QtCore.QPointF:
        ...

    def append(self, value: QtCore.QPointF) -> None:
        ...

    def intersects(self, r: "QPolygonF") -> bool:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#intersects

        **[since 5.10] bool QPolygonF::intersects(const QPolygonF & p ) const**

        Returns `true` if the current polygon intersects at any point the given
        polygon **p**. Also returns `true` if the current polygon contains or is
        contained by any part of **p**.

        Set operations on polygons will treat the polygons as areas. Non-closed
        polygons will be treated as implicitly closed.

        This function was introduced in Qt 5.10.

        **See also** **intersected** ().
        """
        ...

    def subtracted(self, r: "QPolygonF") -> "QPolygonF":
        """
        https://doc.qt.io/qt-6/qpolygonf.html#subtracted

        **QPolygonF QPolygonF::subtracted(const QPolygonF & r ) const**

        Returns a polygon which is **r** subtracted from this polygon.

        Set operations on polygons will treat the polygons as areas. Non-closed
        polygons will be treated as implicitly closed.
        """
        ...

    def intersected(self, r: "QPolygonF") -> "QPolygonF":
        """
        https://doc.qt.io/qt-6/qpolygonf.html#intersected

        **QPolygonF QPolygonF::intersected(const QPolygonF & r ) const**

        Returns a polygon which is the intersection of this polygon and **r**.

        Set operations on polygons will treat the polygons as areas. Non-closed
        polygons will be treated as implicitly closed.

        **See also** **intersects** ().
        """
        ...

    def united(self, r: "QPolygonF") -> "QPolygonF":
        """
        https://doc.qt.io/qt-6/qpolygonf.html#united

        **QPolygonF QPolygonF::united(const QPolygonF & r ) const**

        Returns a polygon which is the union of this polygon and **r**.

        Set operations on polygons will treat the polygons as areas. Non-closed
        polygons will be treated as implicitly closed.

        **See also** **intersected** () and **subtracted** ().
        """
        ...

    def containsPoint(self, pt: QtCore.QPointF, fillRule: QtCore.Qt.FillRule) -> bool:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#containsPoint

        **bool QPolygonF::containsPoint(const QPointF & point , Qt::FillRule
        fillRule ) const**

        Returns `true` if the given **point** is inside the polygon according to
        the specified **fillRule** ; otherwise returns `false`.
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#boundingRect

        **QRectF QPolygonF::boundingRect() const**

        Returns the bounding rectangle of the polygon, or **QRectF** (0,0,0,0)
        if the polygon is empty.

        **See also** **QList::isEmpty** ().
        """
        ...

    def isClosed(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#isClosed

        **bool QPolygonF::isClosed() const**

        Returns `true` if the polygon is closed; otherwise returns `false`.

        A polygon is said to be closed if its start point and end point are
        equal.

        **See also** **QList::first** () and **QList::last** ().
        """
        ...

    def toPolygon(self) -> QPolygon:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#toPolygon

        **QPolygon QPolygonF::toPolygon() const**

        Creates and returns a **QPolygon**  by converting each **QPointF**  to a
        **QPoint** .

        **See also** **QPointF::toPoint** ().
        """
        ...

    @typing.overload
    def translated(self, dx: float, dy: float) -> "QPolygonF":
        """
        https://doc.qt.io/qt-6/qpolygonf.html#translated

        **QPolygonF QPolygonF::translated(const QPointF & offset ) const**

        Returns a copy of the polygon that is translated by the given
        **offset**.

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translated(self, offset: QtCore.QPointF) -> "QPolygonF":
        """
        https://doc.qt.io/qt-6/qpolygonf.html#translated-1

        **QPolygonF QPolygonF::translated(qreal dx , qreal dy ) const**

        This is an overloaded function.

        Returns a copy of the polygon that is translated by ( **dx** , **dy** ).

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translate(self, dx: float, dy: float) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#translate

        **void QPolygonF::translate(const QPointF & offset )**

        Translate all points in the polygon by the given **offset**.

        **See also** **translated** ().
        """
        ...

    @typing.overload
    def translate(self, offset: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#translate-1

        **void QPolygonF::translate(qreal dx , qreal dy )**

        This is an overloaded function.

        Translates all points in the polygon by ( **dx** , **dy** ).

        **See also** **translated** ().
        """
        ...

    def swap(self, other: "QPolygonF") -> None:
        """
        https://doc.qt.io/qt-6/qpolygonf.html#swap

        **void QPolygonF::swap(QPolygonF & other )**

        Swaps polygon **other** with this polygon. This operation is very fast
        and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QRegularExpressionValidator(QValidator):
    """
    https://doc.qt.io/qt-6/qregularexpressionvalidator.html

    **Detailed Description**

    QRegularExpressionValidator uses a regular expression (regexp) to determine
    whether an input string is **Acceptable** , **Intermediate** , or
    **Invalid** . The regexp can either be supplied when the
    QRegularExpressionValidator is constructed, or at a later time.

    If the regexp partially matches against the string, the result is considered
    **Intermediate** . For example, "" and "A" are **Intermediate**  for the
    regexp **[A-Z][0-9]** (whereas "**_** " would be **Invalid** ).

    QRegularExpressionValidator automatically wraps the regular expression in
    the `\\\\A` and `\\\\z` anchors; in other words, it always attempts to do an
    exact match.

    Example of use:

    // regexp: optional '-' followed by between 1 and 3 digits
    **QRegularExpression**  rx("-?\\\\d{1,3}");
        **QValidator**  *validator =
    new **QRegularExpressionValidator** (rx, this);

        **QLineEdit**
    *edit = new **QLineEdit** (this);
        edit->setValidator(validator);

    Below we present some examples of validators. In practice they would
    normally be associated with a widget as in the example above.

    // integers 1 to 9999
        **QRegularExpression**  re("[1-9]\\\\d{0,3}");
    // the validator treats the regexp as "^[1-9]\\\\d{0,3}$"
    **QRegularExpressionValidator**  v(re, 0);
        **QString**  s;
        int pos =
    0;

        s = "0";     v.validate(s, pos);    // returns Invalid
        s =
    "12345"; v.validate(s, pos);    // returns Invalid
        s = "1";
    v.validate(s, pos);    // returns Acceptable

        re.setPattern("\\\\S+");
    // one or more non-whitespace characters
        v.setRegularExpression(re);
    s = "myfile.txt";  v.validate(s, pos); // Returns Acceptable
        s = "my
    file.txt"; v.validate(s, pos); // Returns Invalid

        // A, B or C
    followed by exactly five digits followed by W, X, Y or Z
    re.setPattern("[A-C]\\\\d{5}[W-Z]");
        v.setRegularExpression(re);
        s =
    "a12345Z"; v.validate(s, pos);        // Returns Invalid
        s = "A12345Z";
    v.validate(s, pos);        // Returns Acceptable
        s = "B12";
    v.validate(s, pos);        // Returns Intermediate

        // match most
    'readme' files
        re.setPattern("read\\\\S?me(\\\\.(txt|asc|1st))?");
    re.setPatternOptions(**QRegularExpression** ::CaseInsensitiveOption);
    v.setRegularExpression(re);
        s = "readme";      v.validate(s, pos); //
    Returns Acceptable
        s = "README.1ST";  v.validate(s, pos); // Returns
    Acceptable
        s = "read me.txt"; v.validate(s, pos); // Returns Invalid
    s = "readm";       v.validate(s, pos); // Returns Intermediate

    **See also** **QRegularExpression** , **QIntValidator** , and
    **QDoubleValidator** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionvalidator.html#QRegularExpressi
        onValidator

        **QRegularExpressionValidator::QRegularExpressionValidator(QObject *
        parent = nullptr)**

        Constructs a validator with a **parent** object that accepts any string
        (including an empty one) as valid.
        """
        ...

    @typing.overload
    def __init__(
        self,
        re: QtCore.QRegularExpression,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionvalidator.html#QRegularExpressi
        onValidator-1

        **QRegularExpressionValidator::QRegularExpressionValidator(const
        QRegularExpression & re , QObject * parent = nullptr)**

        Constructs a validator with a **parent** object that accepts all strings
        that match the regular expression **re**.
        """
        ...

    def setRegularExpression(self, re: QtCore.QRegularExpression) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionvalidator.html#regularExpressio
        n-prop

        **regularExpression : QRegularExpression**

        This property holds the regular expression used for validation

        By default, this property contains a regular expression with an empty
        pattern (which therefore matches any string).

        **Access functions:**

        QRegularExpression **regularExpression** () const
        void
        **setRegularExpression** (const QRegularExpression & **re** )

        **Notifier signal:**

        void **regularExpressionChanged** (const QRegularExpression & **re** )

        **Member Function Documentation**
        """
        ...

    def regularExpression(self) -> QtCore.QRegularExpression:
        """
        https://doc.qt.io/qt-6/qregularexpressionvalidator.html#regularExpressio
        n-prop

        **regularExpression : QRegularExpression**

        This property holds the regular expression used for validation

        By default, this property contains a regular expression with an empty
        pattern (which therefore matches any string).

        **Access functions:**

        QRegularExpression **regularExpression** () const
        void
        **setRegularExpression** (const QRegularExpression & **re** )

        **Notifier signal:**

        void **regularExpressionChanged** (const QRegularExpression & **re** )

        **Member Function Documentation**
        """
        ...

    def validate(
        self, input: str, pos: int
    ) -> typing.Tuple[QValidator.State, str, int]:
        """
        https://doc.qt.io/qt-6/qregularexpressionvalidator.html#validate

        **[override virtual] QValidator::State
        QRegularExpressionValidator::validate(QString & input , int & pos )
        const**

        Reimplements: **QValidator::validate(QString &input, int &pos) const** .

        Returns **Acceptable**  if **input** is matched by the regular
        expression for this validator, **Intermediate**  if it has matched
        partially (i.e. could be a valid match if additional valid characters
        are added), and **Invalid**  if **input** is not matched.

        In case the **input** is not matched, the **pos** parameter is set to
        the length of the **input** parameter; otherwise, it is not modified.

        For example, if the regular expression is **\\w\\d\\d** (word-character,
        digit, digit) then "A57" is **Acceptable** , "E5" is **Intermediate** ,
        and "+9" is **Invalid** .

        **See also** **QRegularExpression::match** ().
        """
        ...

    @property
    def regularExpressionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtDesigner import *
import enum


class QDesignerFormWindowManagerInterface(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html

    **Detailed Description**

    QDesignerFormWindowManagerInterface is not intended to be instantiated
    directly. **Qt Designer** uses the form window manager to control the
    various form windows in its workspace. You can retrieve an interface to **Qt
    Designer** 's form window manager using the
    **QDesignerFormEditorInterface::formWindowManager** () function. For
    example:

    **QDesignerFormWindowManagerInterface**  *manager = 0;
    **QDesignerFormWindowInterface**  *formWindow = 0;

                manager
    = formEditor->formWindowManager();
                formWindow =
    manager->formWindow(0);
    manager->setActiveFormWindow(formWindow);

    When implementing a custom widget plugin, a pointer to **Qt Designer** 's
    current **QDesignerFormEditorInterface**  object (`formEditor` in the
    example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter. You
    must subclass the **QDesignerCustomWidgetInterface**  to expose your plugin
    to Qt Designer.

    The form window manager interface provides the **createFormWindow** ()
    function that enables you to create a new form window which you can add to
    the collection of form windows that the manager maintains, using the
    **addFormWindow** () slot. It also provides the **formWindowCount** ()
    function returning the number of form windows currently under the manager's
    control, the **formWindow** () function returning the form window associated
    with a given index, and the **activeFormWindow** () function returning the
    currently selected form window. The **removeFormWindow** () slot allows you
    to reduce the number of form windows the manager must maintain, and the
    **setActiveFormWindow** () slot allows you to change the form window focus
    in **Qt Designer** 's workspace.

    In addition, QDesignerFormWindowManagerInterface contains a collection of
    functions that enables you to intervene and control **Qt Designer** 's form
    editing actions. All these functions return the original action, making it
    possible to propagate the function further after intervention.

    Finally, the interface provides three signals which are emitted when a form
    window is added, when the currently selected form window changes, or when a
    form window is removed, respectively. All the signals carry the form window
    in question as their parameter.

    **See also** **QDesignerFormEditorInterface**  and
    **QDesignerFormWindowInterface** .
    """

    class ActionGroup(enum.Enum):
        StyledPreviewActionGroup: QDesignerFormWindowManagerInterface = ...

    class Action(enum.Enum):
        CutAction: QDesignerFormWindowManagerInterface = ...
        CopyAction: QDesignerFormWindowManagerInterface = ...
        PasteAction: QDesignerFormWindowManagerInterface = ...
        DeleteAction: QDesignerFormWindowManagerInterface = ...
        SelectAllAction: QDesignerFormWindowManagerInterface = ...
        LowerAction: QDesignerFormWindowManagerInterface = ...
        RaiseAction: QDesignerFormWindowManagerInterface = ...
        UndoAction: QDesignerFormWindowManagerInterface = ...
        RedoAction: QDesignerFormWindowManagerInterface = ...
        HorizontalLayoutAction: QDesignerFormWindowManagerInterface = ...
        VerticalLayoutAction: QDesignerFormWindowManagerInterface = ...
        SplitHorizontalAction: QDesignerFormWindowManagerInterface = ...
        SplitVerticalAction: QDesignerFormWindowManagerInterface = ...
        GridLayoutAction: QDesignerFormWindowManagerInterface = ...
        FormLayoutAction: QDesignerFormWindowManagerInterface = ...
        BreakLayoutAction: QDesignerFormWindowManagerInterface = ...
        AdjustSizeAction: QDesignerFormWindowManagerInterface = ...
        SimplifyLayoutAction: QDesignerFormWindowManagerInterface = ...
        DefaultPreviewAction: QDesignerFormWindowManagerInterface = ...
        FormWindowSettingsDialogAction: QDesignerFormWindowManagerInterface = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#QDesigne
        rFormWindowManagerInterface

        **QDesignerFormWindowManagerInterface::QDesignerFormWindowManagerInterfa
        ce(QObject * parent = nullptr)**

        Constructs an interface with the given **parent** for the form window
        manager.
        """
        ...

    def showPluginDialog(self) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#showPlug
        inDialog

        **[pure virtual slot, since 5.0] void
        QDesignerFormWindowManagerInterface::showPluginDialog()**

        Opens a dialog showing the plugins loaded by **Qt Designer** 's and its
        plugin load failures.

        This function was introduced in Qt 5.0.
        """
        ...

    def closeAllPreviews(self) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#closeAll
        Previews

        **[pure virtual slot, since 5.0] void
        QDesignerFormWindowManagerInterface::closeAllPreviews()**

        Close all currently open previews.

        This function was introduced in Qt 5.0.

        **See also** **showPreview** ().
        """
        ...

    def showPreview(self) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#showPrev
        iew

        **[pure virtual slot, since 5.0] void
        QDesignerFormWindowManagerInterface::showPreview()**

        Show a preview of the current form using the default parameters.

        This function was introduced in Qt 5.0.

        **See also** **closeAllPreviews** ().
        """
        ...

    def actionGroup(
        self, actionGroup: "QDesignerFormWindowManagerInterface.ActionGroup"
    ) -> QtGui.QActionGroup:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#actionGr
        oup

        **[pure virtual, since 5.0] QActionGroup *QDesignerFormWindowManagerInte
        rface::actionGroup(QDesignerFormWindowManagerInterface::ActionGroup
        actionGroup ) const**

        Returns the action group specified by the enumeration value
        **actionGroup**.

        This function was introduced in Qt 5.0.
        """
        ...

    def action(
        self, action: "QDesignerFormWindowManagerInterface.Action"
    ) -> QtGui.QAction:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#action

        **[pure virtual, since 5.0] QAction *QDesignerFormWindowManagerInterface
        ::action(QDesignerFormWindowManagerInterface::Action action ) const**

        Returns the action specified by the enumeration value **action**.

        Obsoletes the action accessors of Qt 4.X.

        This function was introduced in Qt 5.0.
        """
        ...

    def setActiveFormWindow(self, formWindow: QDesignerFormWindowInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#setActiv
        eFormWindow

        **[pure virtual slot] void QDesignerFormWindowManagerInterface::setActiv
        eFormWindow(QDesignerFormWindowInterface * formWindow )**

        Sets the given **formWindow** to be the currently active form window in
        **Qt Designer** 's workspace.

        **See also** **activeFormWindow** () and **activeFormWindowChanged** ().
        """
        ...

    def removeFormWindow(self, formWindow: QDesignerFormWindowInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#removeFo
        rmWindow

        **[pure virtual slot] void QDesignerFormWindowManagerInterface::removeFo
        rmWindow(QDesignerFormWindowInterface * formWindow )**

        Removes the given **formWindow** from the collection of windows that
        **Qt Designer** 's form window manager maintains.

        **See also** **formWindow** () and **formWindowRemoved** ().
        """
        ...

    def addFormWindow(self, formWindow: QDesignerFormWindowInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#addFormW
        indow

        **[pure virtual slot] void QDesignerFormWindowManagerInterface::addFormW
        indow(QDesignerFormWindowInterface * formWindow )**

        Adds the given **formWindow** to the collection of windows that **Qt
        Designer** 's form window manager maintains.

        **See also** **formWindowAdded** ().
        """
        ...

    def core(self) -> QDesignerFormEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#core

        **[pure virtual] QDesignerFormEditorInterface
        *QDesignerFormWindowManagerInterface::core() const**

        Returns a pointer to **Qt Designer** 's current
        **QDesignerFormEditorInterface**  object.
        """
        ...

    def createFormWindow(
        self,
        parent: typing.Optional[QtWidgets.QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> QDesignerFormWindowInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#createFo
        rmWindow

        **[pure virtual] QDesignerFormWindowInterface
        *QDesignerFormWindowManagerInterface::createFormWindow(QWidget * parent
        = nullptr, Qt::WindowFlags flags = Qt::WindowFlags())**

        Creates a form window with the given **parent** and the given window
        **flags**.

        **See also** **addFormWindow** ().
        """
        ...

    def formWindow(self, index: int) -> QDesignerFormWindowInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#formWind
        ow

        **[pure virtual] QDesignerFormWindowInterface
        *QDesignerFormWindowManagerInterface::formWindow(int index ) const**

        Returns the form window at the given **index**.

        **See also** **setActiveFormWindow** () and **removeFormWindow** ().
        """
        ...

    def formWindowCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#formWind
        owCount

        **[pure virtual] int
        QDesignerFormWindowManagerInterface::formWindowCount() const**

        Returns the number of form windows maintained by **Qt Designer** 's form
        window manager.
        """
        ...

    def activeFormWindow(self) -> QDesignerFormWindowInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#activeFo
        rmWindow

        **[pure virtual] QDesignerFormWindowInterface
        *QDesignerFormWindowManagerInterface::activeFormWindow() const**

        Returns the currently active form window in **Qt Designer** 's
        workspace.

        **See also** **setActiveFormWindow** () and **removeFormWindow** ().
        """
        ...

    def actionSimplifyLayout(self) -> QtGui.QAction:
        ...

    def actionFormLayout(self) -> QtGui.QAction:
        ...

    @property
    def activeFormWindowChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#activeFo
        rmWindowChanged

        **[signal] void QDesignerFormWindowManagerInterface::activeFormWindowCha
        nged(QDesignerFormWindowInterface * formWindow )**

        This signal is emitted when the contents of the currently active form
        window in **Qt Designer** 's workspace changed. A pointer to the
        currently active **formWindow** is passed as an argument.

        **See also** **activeFormWindow** ().
        """
        ...

    @property
    def formWindowAdded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#formWind
        owAdded

        **[signal] void QDesignerFormWindowManagerInterface::formWindowAdded(QDe
        signerFormWindowInterface * formWindow )**

        This signal is emitted when a new form window is added to the collection
        of windows that **Qt Designer** 's form window manager maintains. A
        pointer to the new **formWindow** is passed as an argument.

        **See also** **addFormWindow** () and **setActiveFormWindow** ().
        """
        ...

    @property
    def formWindowRemoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#formWind
        owRemoved

        **[signal] void QDesignerFormWindowManagerInterface::formWindowRemoved(Q
        DesignerFormWindowInterface * formWindow )**

        This signal is emitted when a form window is removed from the collection
        of windows that **Qt Designer** 's form window manager maintains. A
        pointer to the removed **formWindow** is passed as an argument.

        **See also** **removeFormWindow** ().
        """
        ...

    @property
    def formWindowSettingsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdesignerformwindowmanagerinterface.html#formWind
        owSettingsChanged

        **[signal] void QDesignerFormWindowManagerInterface::formWindowSettingsC
        hanged(QDesignerFormWindowInterface * formWindow )**

        This signal is emitted when the settings of the form window change. It
        can be used to update window titles, etc. accordingly. A pointer to the
        **formWindow** is passed as an argument.

        **See also** **FormWindowSettingsDialogAction** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QFontDialog(QDialog):
    """
    https://doc.qt.io/qt-6/qfontdialog.html

    **Detailed Description**

    A font dialog is created through one of the static **getFont** () functions.

    Examples:

    bool ok;
        **QFont**  font = **QFontDialog** ::getFont(
    &ok, **QFont** ("Helvetica [Cronyx]", 10), this);
        if (ok) {
            //
    the user clicked OK and font is set to the font the user selected
        } else
    {
            // the user canceled the dialog; font is set to the initial
    // value, in this case Helvetica [Cronyx], 10
        }

    The dialog can also be used to set a widget's font directly:

    myWidget.setFont(**QFontDialog** ::getFont(0, myWidget.font()));

    If the user clicks OK the font they chose will be used for myWidget, and if
    they click Cancel the original font is used.

    ![A font dialog in the Fusion widget style.](images/fusion-fontdialog.png)

    **See also** **QFont** , **QFontInfo** , **QFontMetrics** , **QColorDialog**
    , **QFileDialog** , and **Standard Dialogs Example** .
    """

    class FontDialogOption(enum.Flag):
        NoButtons: QFontDialog = ...
        DontUseNativeDialog: QFontDialog = ...
        ScalableFonts: QFontDialog = ...
        NonScalableFonts: QFontDialog = ...
        MonospacedFonts: QFontDialog = ...
        ProportionalFonts: QFontDialog = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#QFontDialog

        **QFontDialog::QFontDialog(QWidget * parent = nullptr)**

        Constructs a standard font dialog.

        Use **setCurrentFont** () to set the initial font attributes.

        The **parent** parameter is passed to the **QDialog**  constructor.

        **See also** **getFont** ().
        """
        ...

    @typing.overload
    def __init__(
        self, initial: QtGui.QFont, parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#QFontDialog-1

        **QFontDialog::QFontDialog(const QFont & initial , QWidget * parent =
        nullptr)**

        Constructs a standard font dialog with the given **parent** and
        specified **initial** font.
        """
        ...

    def setVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#setVisible

        **[override virtual] void QFontDialog::setVisible(bool visible )**

        Reimplements: **QDialog::setVisible** (bool visible).
        """
        ...

    @typing.overload
    def open(self) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#open

        **void QFontDialog::open(QObject * receiver , const char * member )**

        Opens the dialog and connects its **fontSelected** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    @typing.overload
    def open(self, slot: PYQT_SLOT) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#open

        **void QFontDialog::open(QObject * receiver , const char * member )**

        Opens the dialog and connects its **fontSelected** () signal to the slot
        specified by **receiver** and **member**.

        The signal will be disconnected from the slot when the dialog is closed.
        """
        ...

    def options(self) -> "QFontDialog.FontDialogOption":
        """
        https://doc.qt.io/qt-6/qfontdialog.html#options-prop

        **options : FontDialogOptions**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        Options should be set before showing the dialog. Setting them while the
        dialog is visible is not guaranteed to have an immediate effect on the
        dialog (depending on the option and on the platform).

        **Access functions:**

        QFontDialog::FontDialogOptions **options** () const
        void
        **setOptions** (QFontDialog::FontDialogOptions **options** )

        **See also** **setOption** () and **testOption** ().

        **Member Function Documentation**
        """
        ...

    def setOptions(self, options: "QFontDialog.FontDialogOption") -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#options-prop

        **options : FontDialogOptions**

        This property holds the various options that affect the look and feel of
        the dialog

        By default, all options are disabled.

        Options should be set before showing the dialog. Setting them while the
        dialog is visible is not guaranteed to have an immediate effect on the
        dialog (depending on the option and on the platform).

        **Access functions:**

        QFontDialog::FontDialogOptions **options** () const
        void
        **setOptions** (QFontDialog::FontDialogOptions **options** )

        **See also** **setOption** () and **testOption** ().

        **Member Function Documentation**
        """
        ...

    def testOption(self, option: "QFontDialog.FontDialogOption") -> bool:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#testOption

        **bool QFontDialog::testOption(QFontDialog::FontDialogOption option )
        const**

        Returns `true` if the given **option** is enabled; otherwise, returns
        false.

        **See also** **options**  and **setOption** ().
        """
        ...

    def setOption(self, option: "QFontDialog.FontDialogOption", on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#setOption

        **void QFontDialog::setOption(QFontDialog::FontDialogOption option ,
        bool on = true)**

        Sets the given **option** to be enabled if **on** is true; otherwise,
        clears the given **option**.

        **See also** **options**  and **testOption** ().
        """
        ...

    def selectedFont(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#selectedFont

        **QFont QFontDialog::selectedFont() const**

        Returns the font that the user selected by clicking the **OK** or
        equivalent button.

        **Note:** This font is not always the same as the font held by the
        **currentFont**  property since the user can choose different fonts
        before finally selecting the one to use.
        """
        ...

    def currentFont(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#currentFont

        **QFont QFontDialog::currentFont() const**

        Returns the current font.

        **Note:** Getter function for property currentFont.

        **See also** **setCurrentFont** () and **selectedFont** ().
        """
        ...

    def setCurrentFont(self, font: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#setCurrentFont

        **void QFontDialog::setCurrentFont(const QFont & font )**

        Sets the font highlighted in the **QFontDialog**  to the given **font**.

        **Note:** Setter function for property **currentFont** .

        **See also** **currentFont** () and **selectedFont** ().
        """
        ...

    def eventFilter(self, object: QtCore.QObject, event: QtCore.QEvent) -> bool:
        ...

    def done(self, result: int) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#done

        **[override virtual protected] void QFontDialog::done(int result )**

        Reimplements: **QDialog::done** (int r).

        Closes the dialog and sets its result code to **result**. If this dialog
        is shown with **exec** (), done() causes the local event loop to finish,
        and **exec** () to return **result**.

        **See also** **QDialog::done** ().
        """
        ...

    def changeEvent(self, e: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#changeEvent

        **[override virtual protected] void QFontDialog::changeEvent(QEvent * e
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    @typing.overload
    @staticmethod
    def getFont(
        initial: QtGui.QFont,
        parent: typing.Optional[QWidget] = ...,
        caption: str = ...,
        options: "QFontDialog.FontDialogOption" = ...,
    ) -> typing.Tuple[QtGui.QFont, bool]:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#getFont

        **[static] QFont QFontDialog::getFont(bool * ok , const QFont & initial
        , QWidget * parent = nullptr, const QString & title = QString(),
        QFontDialog::FontDialogOptions options = FontDialogOptions())**

        Executes a modal font dialog and returns a font.

        If the user clicks **OK** , the selected font is returned. If the user
        clicks **Cancel** , the **initial** font is returned.

        The dialog is constructed with the given **parent** and the options
        specified in **options**. **title** is shown as the window title of the
        dialog and **initial** is the initially selected font. If the **ok**
        parameter is not-null, the value it refers to is set to true if the user
        clicks **OK** , and set to false if the user clicks **Cancel**.

        Examples:

        bool ok;
            **QFont**  font = **QFontDialog** ::getFont(&ok, **QFont**
        ("Times", 12), this);
            if (ok) {
                // font is set to the font
        the user selected
            } else {
                // the user canceled the dialog;
        font is set to the initial
                // value, in this case Times, 12.
        }

        The dialog can also be used to set a widget's font directly:

        myWidget.setFont(**QFontDialog** ::getFont(0, myWidget.font()));

        In this example, if the user clicks OK the font they chose will be used,
        and if they click Cancel the original font is used.

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QFontDialog**  constructors.
        """
        ...

    @typing.overload
    @staticmethod
    def getFont(
        parent: typing.Optional[QWidget] = ...,
    ) -> typing.Tuple[QtGui.QFont, bool]:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#getFont-1

        **[static] QFont QFontDialog::getFont(bool * ok , QWidget * parent =
        nullptr)**

        This is an overloaded function.

        Executes a modal font dialog and returns a font.

        If the user clicks **OK** , the selected font is returned. If the user
        clicks **Cancel** , the Qt default font is returned.

        The dialog is constructed with the given **parent**. If the **ok**
        parameter is not-null, the value it refers to is set to true if the user
        clicks **OK** , and false if the user clicks **Cancel**.

        Example:

        bool ok;
            **QFont**  font = **QFontDialog** ::getFont(&ok, this);
        if (ok) {
                // font is set to the font the user selected
            }
        else {
                // the user canceled the dialog; font is set to the
        default
                // application font, QApplication::font()
            }

        **Warning:** Do not delete **parent** during the execution of the
        dialog. If you want to do this, you should create the dialog yourself
        using one of the **QFontDialog**  constructors.
        """
        ...

    @property
    def currentFontChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#currentFontChanged

        **[signal] void QFontDialog::currentFontChanged(const QFont & font )**

        This signal is emitted when the current font is changed. The new font is
        specified in **font**.

        The signal is emitted while a user is selecting a font. Ultimately, the
        chosen font may differ from the font currently selected.

        **Note:** Notifier signal for property **currentFont** .

        **See also** **currentFont** , **fontSelected** (), and **selectedFont**
        ().
        """
        ...

    @property
    def fontSelected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qfontdialog.html#fontSelected

        **[signal] void QFontDialog::fontSelected(const QFont & font )**

        This signal is emitted when a font has been selected. The selected font
        is specified in **font**.

        The signal is only emitted when a user has chosen the final font to be
        used. It is not emitted while the user is changing the current font in
        the font dialog.

        **See also** **selectedFont** (), **currentFontChanged** (), and
        **currentFont** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QQmlAbstractUrlInterceptor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlabstracturlinterceptor.html

    **Detailed Description**

    QQmlAbstractUrlInterceptor is an interface which can be used to alter URLs
    before they are used by the QML engine. This is primarily useful for
    altering file urls into other file urls, such as selecting different
    graphical assets for the current platform.

    Relative URLs are intercepted after being resolved against the file path of
    the current QML context. URL interception also occurs after setting the base
    path for a loaded QML file. This means that the content loaded for that QML
    file uses the intercepted URL, but inside the file the pre-intercepted URL
    is used for resolving relative paths. This allows for interception of .qml
    file loading without needing all paths (or local types) inside intercepted
    content to insert a different relative path.

    Compared to setNetworkAccessManagerFactory, QQmlAbstractUrlInterceptor
    affects all URLs and paths, including local files and embedded resource
    files. QQmlAbstractUrlInterceptor is synchronous, and for asynchronous files
    must return a url with an asynchronous scheme (such as http or a custom
    scheme handled by your own custom QNetworkAccessManager). You can use a
    QQmlAbstractUrlInterceptor to change file URLs into networked URLs which are
    handled by your own custom QNetworkAccessManager.

    To implement support for a custom networked scheme, see
    setNetworkAccessManagerFactory.
    """

    class DataType(enum.Enum):
        QmlFile: QQmlAbstractUrlInterceptor = ...
        JavaScriptFile: QQmlAbstractUrlInterceptor = ...
        QmldirFile: QQmlAbstractUrlInterceptor = ...
        UrlString: QQmlAbstractUrlInterceptor = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlabstracturlinterceptor.html#QQmlAbstractUrlIn
        terceptor

        **QQmlAbstractUrlInterceptor::QQmlAbstractUrlInterceptor()**

        Constructor for QQmlAbstractUrlInterceptor.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlAbstractUrlInterceptor") -> None:
        """
        https://doc.qt.io/qt-6/qqmlabstracturlinterceptor.html#QQmlAbstractUrlIn
        terceptor

        **QQmlAbstractUrlInterceptor::QQmlAbstractUrlInterceptor()**

        Constructor for QQmlAbstractUrlInterceptor.
        """
        ...

    def intercept(
        self, path: QtCore.QUrl, type: "QQmlAbstractUrlInterceptor.DataType"
    ) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qqmlabstracturlinterceptor.html#intercept

        **[pure virtual] QUrl QQmlAbstractUrlInterceptor::intercept(const QUrl &
        url , QQmlAbstractUrlInterceptor::DataType type )**

        A pure virtual function where you can intercept the **url**. The
        returned value is taken as the new value for the url. The type of url
        being intercepted is given by the **type** variable.

        Your implementation of this function must be thread-safe, as it can be
        called from multiple threads at the same time.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QMatrix3x4(PyQt6.sip.simplewrapper):
    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, other: "QMatrix3x4") -> None:
        ...

    @typing.overload
    def __init__(self, values: typing.Sequence[float]) -> None:
        ...

    def transposed(self) -> QMatrix4x3:
        ...

    def fill(self, value: float) -> None:
        ...

    def setToIdentity(self) -> None:
        ...

    def isIdentity(self) -> bool:
        ...

    def __setitem__(self, a0: typing.Any, a1: float) -> None:
        ...

    def __getitem__(self, a0: typing.Any) -> typing.Any:
        ...

    def copyDataTo(self) -> typing.List[float]:
        ...

    def data(self) -> typing.List[float]:
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QTextObject(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qtextobject.html

    **Detailed Description**

    The common grouping text objects are lists (**QTextList** ), frames
    (**QTextFrame** ), and tables (**QTextTable** ). A text object has an
    associated **format** () and **document** ().

    There are essentially two kinds of text objects: those that are used with
    blocks (block formats), and those that are used with characters (character
    formats). The first kind are derived from **QTextBlockGroup** , and the
    second kind from **QTextFrame** .

    You rarely need to use this class directly. When creating custom text
    objects, you will also need to reimplement **QTextDocument::createObject**
    () which acts as a factory method for creating text objects.

    **See also** **QTextDocument**  and **Text Object Example** .
    """

    def __init__(self, doc: QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qtextobject.html#QTextObject

        **[protected] QTextObject::QTextObject(QTextDocument * document )**

        Creates a new QTextObject for the given **document**.

        **Warning:** This function should never be called directly, but only
        from **QTextDocument::createObject** ().
        """
        ...

    def objectIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextobject.html#objectIndex

        **int QTextObject::objectIndex() const**

        Returns the object index of this object. This can be used together with
        **QTextFormat::setObjectIndex** ().
        """
        ...

    def document(self) -> QTextDocument:
        """
        https://doc.qt.io/qt-6/qtextobject.html#document

        **QTextDocument *QTextObject::document() const**

        Returns the document this object belongs to.

        **See also** **format** ().
        """
        ...

    def formatIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextobject.html#formatIndex

        **int QTextObject::formatIndex() const**

        Returns the index of the object's format in the document's internal list
        of formats.

        **See also** **QTextDocument::allFormats** ().
        """
        ...

    def format(self) -> QTextFormat:
        """
        https://doc.qt.io/qt-6/qtextobject.html#format

        **QTextFormat QTextObject::format() const**

        Returns the text object's format.

        **See also** **setFormat** () and **document** ().
        """
        ...

    def setFormat(self, format: QTextFormat) -> None:
        """
        https://doc.qt.io/qt-6/qtextobject.html#setFormat

        **[protected] void QTextObject::setFormat(const QTextFormat & format )**

        Sets the text object's **format**.

        **See also** **format** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomCharacterData(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomcharacterdata.html

    **Detailed Description**

    Character data as used in XML specifies a generic data string. More
    specialized versions of this class are **QDomText** , **QDomComment**  and
    **QDomCDATASection** .

    The data string is set with **setData** () and retrieved with **data** ().
    You can retrieve a portion of the data string using **substringData** ().
    Extra data can be appended with **appendData** (), or inserted with
    **insertData** (). Portions of the data string can be deleted with
    **deleteData** () or replaced with **replaceData** (). The length of the
    data string is returned by **length** ().

    The node type of the node containing this character data is returned by
    **nodeType** ().

    **See also** **QDomText** , **QDomComment** , and **QDomCDATASection** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#QDomCharacterData

        **QDomCharacterData::QDomCharacterData()**

        Constructs an empty character data object.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomCharacterData") -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#QDomCharacterData-1

        **QDomCharacterData::QDomCharacterData(const QDomCharacterData & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#nodeType

        **QDomNode::NodeType QDomCharacterData::nodeType() const**

        Returns the type of node this object refers to (i.e. `TextNode`,
        `CDATASectionNode`, `CommentNode` or `CharacterDataNode`). For a **null
        node** , returns `CharacterDataNode`.
        """
        ...

    def setData(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#setData

        **void QDomCharacterData::setData(const QString & v )**

        Sets this object's string to **v**.

        **See also** **data** ().
        """
        ...

    def data(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#data

        **QString QDomCharacterData::data() const**

        Returns the string stored in this object.

        If the node is a **null node** , it will return an empty string.

        **See also** **setData** ().
        """
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#length

        **int QDomCharacterData::length() const**

        Returns the length of the stored string.
        """
        ...

    def replaceData(self, offset: int, count: int, arg: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#replaceData

        **void QDomCharacterData::replaceData(unsigned long offset , unsigned
        long count , const QString & arg )**

        Replaces the substring of length **count** starting at position
        **offset** with the string **arg**.
        """
        ...

    def deleteData(self, offset: int, count: int) -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#deleteData

        **void QDomCharacterData::deleteData(unsigned long offset , unsigned
        long count )**

        Deletes a substring of length **count** from position **offset**.
        """
        ...

    def insertData(self, offset: int, arg: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#insertData

        **void QDomCharacterData::insertData(unsigned long offset , const
        QString & arg )**

        Inserts the string **arg** into the stored string at position
        **offset**.
        """
        ...

    def appendData(self, arg: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#appendData

        **void QDomCharacterData::appendData(const QString & arg )**

        Appends the string **arg** to the stored string.
        """
        ...

    def substringData(self, offset: int, count: int) -> str:
        """
        https://doc.qt.io/qt-6/qdomcharacterdata.html#substringData

        **QString QDomCharacterData::substringData(unsigned long offset ,
        unsigned long count )**

        Returns the substring of length **count** from position **offset**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QTapGesture(QGesture):
    """
    https://doc.qt.io/qt-6/qtapgesture.html

    **Detailed Description**

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **See also** **QPanGesture**  and **QPinchGesture** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def setPosition(self, pos: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qtapgesture.html#position-prop

        **position : QPointF**

        This property holds the position of the tap

        **Access functions:**

        QPointF **position** () const
        void **setPosition** (const QPointF &
        **pos** )

        **Member Function Documentation**
        """
        ...

    def position(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qtapgesture.html#position-prop

        **position : QPointF**

        This property holds the position of the tap

        **Access functions:**

        QPointF **position** () const
        void **setPosition** (const QPointF &
        **pos** )

        **Member Function Documentation**
        """
        ...
